# Make your component interactive

This section will help you add interactivity to your applications and exploratory workflows.

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`zap;2.5em;sd-mr-1 sd-animate-grow50` Add interactivity to a function
:link: bind_function
:link-type: doc

Discover how to bind widgets to a function to add interactivity.
:::


:::{grid-item-card} {octicon}`gear;2.5em;sd-mr-1 sd-animate-grow50` Build self-updating components
:link: bind_generators
:link-type: doc

How to use Python generators with `pn.bind` to build components that update themselves.
:::


:::{grid-item-card} {octicon}`package-dependencies;2.5em;sd-mr-1 sd-animate-grow50` Add reactivity to components
:link: bind_component
:link-type: doc

Discover how to bind parameters, widgets, and bound functions to components.
:::

:::{grid-item-card} {octicon}`workflow;2.5em;sd-mr-1 sd-animate-grow50` Build reactive data pipelines
:link: hvplot_interactive
:link-type: doc

How to use `hvplot.interactive` with widgets to make your data workflows interactive
:::

::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

bind_function
bind_generators
bind_component
hvplot_interactive
```
